embassy-nrf

Crates

git

Versions

nrf54l05-app-s

Flavors

Radio

Struct Radio 

pub struct Radio { /* private fields */ }
2.4 GHz radio 0.

Implementations

Source

impl Radio

pub const unsafe fn from_ptr(ptr: *mut ()) -> Radio

pub const fn as_ptr(&self) -> *mut ()

pub const fn tasks_txen(self) -> Reg<u32, W>

Enable RADIO in TX mode.

pub const fn tasks_rxen(self) -> Reg<u32, W>

Enable RADIO in RX mode.

pub const fn tasks_start(self) -> Reg<u32, W>

Start RADIO.

pub const fn tasks_stop(self) -> Reg<u32, W>

Stop RADIO.

pub const fn tasks_disable(self) -> Reg<u32, W>

Disable RADIO.

pub const fn tasks_rssistart(self) -> Reg<u32, W>

Start the RSSI and take one single sample of the receive signal strength.

pub const fn tasks_bcstart(self) -> Reg<u32, W>

Start the bit counter.

pub const fn tasks_bcstop(self) -> Reg<u32, W>

Stop the bit counter.

pub const fn tasks_edstart(self) -> Reg<u32, W>

Start the energy detect measurement used in IEEE 802.15.4 mode.

pub const fn tasks_edstop(self) -> Reg<u32, W>

Stop the energy detect measurement.

pub const fn tasks_ccastart(self) -> Reg<u32, W>

Start the clear channel assessment used in IEEE 802.15.4 mode.

pub const fn tasks_ccastop(self) -> Reg<u32, W>

Stop the clear channel assessment.

pub const fn tasks_auxdatadmastart(self) -> Reg<u32, W>

Start DMA transaction of acquisition.

pub const fn tasks_auxdatadmastop(self) -> Reg<u32, W>

Stop ongoing DMA transaction of acquisition.

pub const fn tasks_pllen(self) -> Reg<u32, W>

Enable RADIO in PLL mode (standby for either TX or RX).

pub const fn tasks_cstonesstart(self) -> Reg<u32, W>

Start tone processing for channel sounding.

pub const fn tasks_softreset(self) -> Reg<u32, W>

Reset all public registers, but with these exceptions: DMA registers and EVENT/INTEN/SUBSCRIBE/PUBLISH registers. Only to be used in DISABLED state.

pub const fn subscribe_txen(self) -> Reg<Subscribe, RW>

Subscribe configuration for task TXEN.

pub const fn subscribe_rxen(self) -> Reg<Subscribe, RW>

Subscribe configuration for task RXEN.

pub const fn subscribe_start(self) -> Reg<Subscribe, RW>

Subscribe configuration for task START.

pub const fn subscribe_stop(self) -> Reg<Subscribe, RW>

Subscribe configuration for task STOP.

pub const fn subscribe_disable(self) -> Reg<Subscribe, RW>

Subscribe configuration for task DISABLE.

pub const fn subscribe_rssistart(self) -> Reg<Subscribe, RW>

Subscribe configuration for task RSSISTART.

pub const fn subscribe_bcstart(self) -> Reg<Subscribe, RW>

Subscribe configuration for task BCSTART.

pub const fn subscribe_bcstop(self) -> Reg<Subscribe, RW>

Subscribe configuration for task BCSTOP.

pub const fn subscribe_edstart(self) -> Reg<Subscribe, RW>

Subscribe configuration for task EDSTART.

pub const fn subscribe_edstop(self) -> Reg<Subscribe, RW>

Subscribe configuration for task EDSTOP.

pub const fn subscribe_ccastart(self) -> Reg<Subscribe, RW>

Subscribe configuration for task CCASTART.

pub const fn subscribe_ccastop(self) -> Reg<Subscribe, RW>

Subscribe configuration for task CCASTOP.

pub const fn subscribe_auxdatadmastart(self) -> Reg<Subscribe, RW>

Subscribe configuration for task AUXDATADMASTART.

pub const fn subscribe_auxdatadmastop(self) -> Reg<Subscribe, RW>

Subscribe configuration for task AUXDATADMASTOP.

pub const fn subscribe_pllen(self) -> Reg<Subscribe, RW>

Subscribe configuration for task PLLEN.

pub const fn subscribe_cstonesstart(self) -> Reg<Subscribe, RW>

Subscribe configuration for task CSTONESSTART.

pub const fn subscribe_softreset(self) -> Reg<Subscribe, RW>

Subscribe configuration for task SOFTRESET.

pub const fn events_ready(self) -> Reg<u32, RW>

RADIO has ramped up and is ready to be started.

pub const fn events_txready(self) -> Reg<u32, RW>

RADIO has ramped up and is ready to be started TX path.

pub const fn events_rxready(self) -> Reg<u32, RW>

RADIO has ramped up and is ready to be started RX path.

pub const fn events_address(self) -> Reg<u32, RW>

Address sent or received.

pub const fn events_framestart(self) -> Reg<u32, RW>

IEEE 802.15.4 length field received.

pub const fn events_payload(self) -> Reg<u32, RW>

Packet payload sent or received.

pub const fn events_end(self) -> Reg<u32, RW>

Memory access for packet data has been completed.

pub const fn events_phyend(self) -> Reg<u32, RW>

The last bit is sent on air or last bit is received.

pub const fn events_disabled(self) -> Reg<u32, RW>

RADIO has been disabled.

pub const fn events_devmatch(self) -> Reg<u32, RW>

A device address match occurred on the last received packet.

pub const fn events_devmiss(self) -> Reg<u32, RW>

No device address match occurred on the last received packet.

pub const fn events_crcok(self) -> Reg<u32, RW>

Packet received with CRC ok.

pub const fn events_crcerror(self) -> Reg<u32, RW>

Packet received with CRC error.

pub const fn events_bcmatch(self) -> Reg<u32, RW>

Bit counter reached bit count value.

pub const fn events_edend(self) -> Reg<u32, RW>

Sampling of energy detection complete (a new ED sample is ready for readout from the RADIO.EDSAMPLE register).

pub const fn events_edstopped(self) -> Reg<u32, RW>

The sampling of energy detection has stopped.

pub const fn events_ccaidle(self) -> Reg<u32, RW>

Wireless medium in idle - clear to send.

pub const fn events_ccabusy(self) -> Reg<u32, RW>

Wireless medium busy - do not send.

pub const fn events_ccastopped(self) -> Reg<u32, RW>

The CCA has stopped.

pub const fn events_rateboost(self) -> Reg<u32, RW>

Ble_LR CI field received, receive mode is changed from Ble_LR125Kbit to Ble_LR500Kbit.

pub const fn events_mhrmatch(self) -> Reg<u32, RW>

MAC header match found.

pub const fn events_sync(self) -> Reg<u32, RW>

Initial sync detected.

pub const fn events_ctepresent(self) -> Reg<u32, RW>

CTEInfo byte is received.

pub const fn events_pllready(self) -> Reg<u32, RW>

PLL has settled and RADIO is ready to be enabled in either TX or RX mode.

pub const fn events_rxaddress(self) -> Reg<u32, RW>

Address received.

pub const fn events_auxdatadmaend(self) -> Reg<u32, RW>

AUXDATA DMA end.

pub const fn events_cstonesend(self) -> Reg<u32, RW>

The channel sounding tone processing is complete.

pub const fn publish_ready(self) -> Reg<Publish, RW>

Publish configuration for event READY.

pub const fn publish_txready(self) -> Reg<Publish, RW>

Publish configuration for event TXREADY.

pub const fn publish_rxready(self) -> Reg<Publish, RW>

Publish configuration for event RXREADY.

pub const fn publish_address(self) -> Reg<Publish, RW>

Publish configuration for event ADDRESS.

pub const fn publish_framestart(self) -> Reg<Publish, RW>

Publish configuration for event FRAMESTART.

pub const fn publish_payload(self) -> Reg<Publish, RW>

Publish configuration for event PAYLOAD.

pub const fn publish_end(self) -> Reg<Publish, RW>

Publish configuration for event END.

pub const fn publish_phyend(self) -> Reg<Publish, RW>

Publish configuration for event PHYEND.

pub const fn publish_disabled(self) -> Reg<Publish, RW>

Publish configuration for event DISABLED.

pub const fn publish_devmatch(self) -> Reg<Publish, RW>

Publish configuration for event DEVMATCH.

pub const fn publish_devmiss(self) -> Reg<Publish, RW>

Publish configuration for event DEVMISS.

pub const fn publish_crcok(self) -> Reg<Publish, RW>

Publish configuration for event CRCOK.

pub const fn publish_crcerror(self) -> Reg<Publish, RW>

Publish configuration for event CRCERROR.

pub const fn publish_bcmatch(self) -> Reg<Publish, RW>

Publish configuration for event BCMATCH.

pub const fn publish_edend(self) -> Reg<Publish, RW>

Publish configuration for event EDEND.

pub const fn publish_edstopped(self) -> Reg<Publish, RW>

Publish configuration for event EDSTOPPED.

pub const fn publish_ccaidle(self) -> Reg<Publish, RW>

Publish configuration for event CCAIDLE.

pub const fn publish_ccabusy(self) -> Reg<Publish, RW>

Publish configuration for event CCABUSY.

pub const fn publish_ccastopped(self) -> Reg<Publish, RW>

Publish configuration for event CCASTOPPED.

pub const fn publish_rateboost(self) -> Reg<Publish, RW>

Publish configuration for event RATEBOOST.

pub const fn publish_mhrmatch(self) -> Reg<Publish, RW>

Publish configuration for event MHRMATCH.

pub const fn publish_sync(self) -> Reg<Publish, RW>

Publish configuration for event SYNC.

pub const fn publish_ctepresent(self) -> Reg<Publish, RW>

Publish configuration for event CTEPRESENT.

pub const fn publish_pllready(self) -> Reg<Publish, RW>

Publish configuration for event PLLREADY.

pub const fn publish_rxaddress(self) -> Reg<Publish, RW>

Publish configuration for event RXADDRESS.

pub const fn publish_auxdatadmaend(self) -> Reg<Publish, RW>

Publish configuration for event AUXDATADMAEND.

pub const fn publish_cstonesend(self) -> Reg<Publish, RW>

Publish configuration for event CSTONESEND.

pub const fn shorts(self) -> Reg<Shorts, RW>

Shortcuts between local events and tasks.

pub const fn intenset0(self, n: usize) -> Reg<Int0, RW>

Enable interrupt.

pub const fn intenset1(self, n: usize) -> Reg<Int1, RW>

Enable interrupt.

pub const fn intenclr0(self, n: usize) -> Reg<Int0, RW>

Disable interrupt.

pub const fn intenclr1(self, n: usize) -> Reg<Int1, RW>

Disable interrupt.

pub const fn mode(self) -> Reg<RadioMode, RW>

Data rate and modulation.

pub const fn phyendtxdelay(self) -> Reg<Phyendtxdelay, RW>

Configurable delay of PHYEND event for TX.

pub const fn state(self) -> Reg<State, R>

Current radio state.

pub const fn edctrl(self) -> Reg<Edctrl, RW>

IEEE 802.15.4 energy detect control.

pub const fn edsample(self) -> Reg<Edsample, R>

IEEE 802.15.4 energy detect level.

pub const fn ccactrl(self) -> Reg<Ccactrl, RW>

IEEE 802.15.4 clear channel assessment control.

pub const fn datawhite(self) -> Reg<Datawhite, RW>

Data whitening configuration.

pub const fn auxdata(self) -> Auxdata

Unspecified.

pub const fn auxdatadma(self, n: usize) -> Auxdatadma

Unspecified.

pub const fn timing(self) -> Reg<Timing, RW>

Timing.

pub const fn frequency(self) -> Reg<Frequency, RW>

Frequency.

pub const fn txpower(self) -> Reg<Txpower, RW>

Output power.

pub const fn tifs(self) -> Reg<Tifs, RW>

Interframe spacing in us.

pub const fn rssisample(self) -> Reg<Rssisample, R>

RSSI sample.

pub const fn rxgain(self) -> Rxgain

Unspecified.

pub const fn freqfinetune(self) -> Reg<Freqfinetune, RW>

Fine tuning of the RF frequency.

pub const fn feconfig(self) -> Reg<Feconfig, RW>

Config register.

pub const fn cfo_stat(self) -> Reg<CfoStat, R>

Carrier freq. offset estimate.

pub const fn dbccorr(self) -> Reg<Dbccorr, RW>

Correlator thresholds.

pub const fn dfemode(self) -> Reg<Dfemode, RW>

Whether to use Angle-of-Arrival (AOA) or Angle-of-Departure (AOD).

pub const fn dfestatus(self) -> Reg<Dfestatus, R>

DFE status information.

pub const fn dfectrl1(self) -> Reg<Dfectrl1, RW>

Various configuration for Direction finding.

pub const fn dfectrl2(self) -> Reg<Dfectrl2, RW>

Start offset for Direction finding.

pub const fn switchpattern(self) -> Reg<Switchpattern, RW>

GPIO patterns to be used for each antenna.

pub const fn clearpattern(self) -> Reg<Clearpattern, W>

Clear the GPIO pattern array for antenna control.

pub const fn psel(self) -> Psel

Unspecified.

pub const fn dfepacket(self) -> Dfepacket

DFE packet EasyDMA channel.

pub const fn crcstatus(self) -> Reg<Crcstatus, R>

CRC status.

pub const fn rxmatch(self) -> Reg<Rxmatch, R>

Received address.

pub const fn rxcrc(self) -> Reg<Rxcrc, R>

CRC field of previously received packet.

pub const fn dai(self) -> Reg<Dai, R>

Device address match index.

pub const fn pdustat(self) -> Reg<Pdustat, R>

Payload status.

pub const fn pcnf0(self) -> Reg<Pcnf0, RW>

Packet configuration register 0.

pub const fn pcnf1(self) -> Reg<Pcnf1, RW>

Packet configuration register 1.

pub const fn base0(self) -> Reg<u32, RW>

Base address 0.

pub const fn base1(self) -> Reg<u32, RW>

Base address 1.

pub const fn prefix0(self) -> Reg<Prefix0, RW>

Prefixes bytes for logical addresses 0-3.

pub const fn prefix1(self) -> Reg<Prefix1, RW>

Prefixes bytes for logical addresses 4-7.

pub const fn txaddress(self) -> Reg<Txaddress, RW>

Transmit address select.

pub const fn rxaddresses(self) -> Reg<Rxaddresses, RW>

Receive address select.

pub const fn crccnf(self) -> Reg<Crccnf, RW>

CRC configuration.

pub const fn crcpoly(self) -> Reg<Crcpoly, RW>

CRC polynomial.

pub const fn crcinit(self) -> Reg<Crcinit, RW>

CRC initial value.

pub const fn dab(self, n: usize) -> Reg<u32, RW>

Description collection: Device address base segment n.

pub const fn dap(self, n: usize) -> Reg<Dap, RW>

Description collection: Device address prefix n.

pub const fn dacnf(self) -> Reg<Dacnf, RW>

Device address match configuration.

pub const fn bcc(self) -> Reg<u32, RW>

Bit counter compare.

pub const fn ctestatus(self) -> Reg<Ctestatus, R>

CTEInfo parsed from received packet.

pub const fn mhrmatchconf(self) -> Reg<u32, RW>

Search pattern configuration.

pub const fn mhrmatchmask(self) -> Reg<u32, RW>

Pattern mask.

pub const fn sfd(self) -> Reg<Sfd, RW>

IEEE 802.15.4 start of frame delimiter.

pub const fn cteinlineconf(self) -> Reg<Cteinlineconf, RW>

Configuration for CTE inline mode.

pub const fn packetptr(self) -> Reg<u32, RW>

Packet pointer.

pub const fn cstones(self) -> Cstones

Unspecified.

pub const fn rtt(self) -> Rtt

Unspecified.